/* CCLENV.CMD */
/***********************************************************************/
/*                                                                     */
/* MODULE NAME        CCLENV.CMD                                       */
/*                                                                     */
/* DESCRIPTIVE NAME   Set-up IBM CICS Client for OS/2 Environment      */
/*                                                                     */
/* Statement:         Licensed Materials - Property of IBM             */
/*                                                                     */
/*                    17H7627                                          */
/*                    (c) Copyright IBM Corp. 1988, 1994.              */
/*                                                                     */
/*                    See Copyright Instructions.                      */
/*                                                                     */
/*                    All rights reserved.                             */
/*                                                                     */
/*                    U.S. Government Users Restricted Rights - use,   */
/*                    duplication or disclosure restricted by GSA      */
/*                    ADP Schedule Contract with IBM Corp.             */
/*                                                                     */
/* Status:            Version 1 Release 0                              */
/*                                                                     */
/*  NOTES :-                                                           */
/*    DEPENDENCIES = None                                              */
/*                   None                                              */
/*    RESTRICTIONS = None                                              */
/*    MODULE TYPE  = Command file                                      */
/*    PROCESSOR    = PS/2 and PC                                       */
/*                                                                     */
/***********************************************************************/
trace n
rc = 0
'@ECHO OFF'
/*---------------------------------------------------------------------*/
/* This purpose of this CMD file is to establish a set of variables    */
/* that identify where the IBM CICS Client for OS/2 is installed, for  */
/* example on a network drive, and is used by the CCLFOLD.CMD to       */
/* create the necessary folder and program definitions.                */
/*                                                                     */
/* Note that these definitions must follow REXX syntax rules           */
/* as well as OS/2 file naming conventions.                            */
/*                                                                     */
/*---------------------------------------------------------------------*/
/*  Establish CCLDRV, CCLHLD and BOOTDRIVE Qualifiers                  */
/*                                                                     */
ccldrv='G:'                       /* This is the drive ID              */
cclhld='CICSCLIO'                 /* and the highlevel qualifier       */
bootdrive='C:'                    /* This is the OS/2 boot drive id    */
                                  /* and is where the OS2\VIEW.EXE is  */
                                  /* located                           */
x=SetValue('CCLDRV='ccldrv)
x=SetValue('CCLHLD='cclhld)
x=SetValue('BOOTDRIVE='bootdrive)

/* The value for UserWrk will be added dynamically to the end of the   */
/* OS/2 PATH definition.  Automatically included will be the \BIN      */
/* definition, based on the CCLDRV\CCLHLD defined above                */
UserWrk           =''


/* For assistance with development of Client based applications, the   */
/* following variables can be defined and will be set when this CMD    */
/* file is run.  IMPORTANT: Note that the IBM CICS Client for OS/2     */
/* does NOT supply any sample compile/link cmd files that make use     */
/* of this interface.                                                  */

/* point to any .LIB file                                              */
UserLib           =bootdrive'\OS2'   /* Assumes OS/2 is on the C drive */

/*                           COBOL language options                    */
UserCobdir        =''
UserCobcpy        =''
UserCobwrk        =''
UserCobxil        =''
UserCobidy        =''

/*                           C language options                        */
UserInclude       =''
UserIcc           =''

/*                           PL/I language options                     */
UserPLIInclude    =''
UserPLICeeOptions ='NOTEST'

/* user preferred editor, kept for compatability with CICS for OS/2 cmds */
UserEdit          =''

/*---------------------------------------------------------------------*/
/* Continue checking and setting                                       */
/*---------------------------------------------------------------------*/
/* Get name of this program */
parse upper source . . execname
execname = filespec('name', execname)
execname = substr(execname, 1, lastpos('.', execname) - 1)

/* get input  */
parse arg options

/* Banner */
say '------------------------------------------------------------------------------'
say ' 'execname' - Define & Set environment variables - IBM CICS Client for OS/2 '
say '------------------------------------------------------------------------------'

/*---------------------------------------------------------------------*/
/* Has the CCL drive and directory been set on installation?          */
/*---------------------------------------------------------------------*/
if GetValue('CCLDRV') = '::' then do
   /*------------------------------------------------------------------*/
   /* No, so get drive and path from where this file is found          */
   /*------------------------------------------------------------------*/
   parse upper source . . sourcefile
   ccldrv = filespec('DRIVE', sourcefile)
   cclhld = filespec('PATH', sourcefile)
   parse upper value right(ccldrv, 6) with r1
   if r1 = '\UTIL\' then do
      cclhld = substr(cclhld, 2, length(cclhld) - 7);
   end; else do
      cclhld = substr(cclhld, 2, length(cclhld) - 2);
   end
   x=SetValue('CCLDRV='ccldrv)
   x=SetValue('CCLHLD='cclhld)
end

If GetValue('CCLSET') = '' Then
  Do
      /*---------------------------------------------------------------*/
      /*  Obtain Environment Variables and set the rest                */
      /*---------------------------------------------------------------*/
       ccldrv=GetValue('CCLDRV')
       cclhld=GetValue('CCLHLD')
       ccldir=ccldrv'\'cclhld

      /*---------------------------------------------------------------*/
      /*  Remember the editor of choice                                */
      /*---------------------------------------------------------------*/
       x=SetValue('USEREDIT='UserEdit)

      /*---------------------------------------------------------------*/
      /*  Put it all together                                          */
      /*---------------------------------------------------------------*/
       x=SetValue('CCLWRK='Semi(userwrk)||ccldir'\BIN;')

      /*---------------------------------------------------------------*/
      /* Set the PATH to include CICS Client for OS/2 Information      */
      /*---------------------------------------------------------------*/
       x=SetValue('PATH='Semi(GetValue('PATH'))||ccldir'\BIN;')

/*=========================================================================*/
/*  Start of section for C and C Set/2                                     */
/*=========================================================================*/
      /*---------------------------------------------------------------*/
      /* Set values when developing with the C language                */
      /*---------------------------------------------------------------*/
       x=SetValue('INCLUDE='Semi(UserInclude)||,
                            ccldir'\INCLUDE;'||,
                            Semi(GetValue('INCLUDE')))

/*=========================================================================*/
/*    End of section for C and C Set/2                                     */
/*=========================================================================*/

/*=========================================================================*/
/*  Start of section for PL/I                                              */
/*=========================================================================*/
      /*---------------------------------------------------------------*/
      /* Set values when developing with the PL/I language             */
      /*---------------------------------------------------------------*/

      x=SetValue('INCLUDE='Semi(UserPLIInclude)||,
                           ccldir'\PLIHDR;'||,
                           Semi(GetValue('INCLUDE')))

      oceeoptions     =GetValue('CEE.OPTIONS')

      if strip(UserPLICeeOptions) = '' &,
         strip(oceeoptions)       = '' then
          'SET CEE.OPTIONS='
      else
         x=SetValue('CEE.OPTIONS='Coma(UserPLICeeOptions)||Coma(oceeoptions))

/*=========================================================================*/
/*    End of section for PL/I                                              */
/*=========================================================================*/

/*=========================================================================*/
/*  Start of section for COBOL                                             */
/*=========================================================================*/

      /*---------------------------------------------------------------*/
      /*  COBOL Environment variables are set in CCLENV               */
      /*---------------------------------------------------------------*/
       x=SetValue('COBCPY='Semi(UserCobcpy)||,
                           ccldir'\COPYBOOK;'||,
                           Semi(GetValue('COBCPY')))
       x=SetValue('COBWRK='Semi(UserCobwrk)||,
                           Semi(GetValue('COBWRK')))
       x=SetValue('COBDIR='Semi(UserCobdir)||,
                           Semi(GetValue('COBDIR')))
       x=SetValue('COBXIL='Semi(UserCobxil)||,
                           Semi(GetValue('COBXIL')))
       x=SetValue('COBIDY='Semi(UserCobidy)||,
                           Semi(GetValue('COBIDY')))

/*=========================================================================*/
/*    End of section for COBOL                                             */
/*=========================================================================*/

      /*---------------------------------------------------------------*/
      /* Set up Lib for the Link Step. for C, PL/I and COBOL           */
      /*---------------------------------------------------------------*/
      x=SetValue('LIB='ccldir'\LIB;'||,
                       Semi(UserLib)||,
                       Semi(GetValue('LIB')))

      /*---------------------------------------------------------------*/
      /*  Last Step - set CCLSET ON to show this code has run          */
      /*---------------------------------------------------------------*/
       x=SetValue('CCLSET=ON')
End
Exit
/*---------------------------------------------------------------------*/
/* Subroutines                                                         */
/*---------------------------------------------------------------------*/
/*---------------------------------------------------------------------*/
/* Set a new environment variable                                      */
/*---------------------------------------------------------------------*/
SetValue: Procedure
  Parse Arg EnvVal                              /* respect lower case  */
  Parse Value EnvVal with EnvVal '=' NewVal     /* break into two      */
  res  = value(EnvVal,NewVal,'OS2ENVIRONMENT')  /* Set the Variable    */
Return res
/*---------------------------------------------------------------------*/
/* Get a     environment variable                                      */
/*---------------------------------------------------------------------*/
GetValue: Procedure             /* Obtain an environment variable      */
  Arg EnvVal .
  res  = value(EnvVal,,'OS2ENVIRONMENT')
Return res
/*---------------------------------------------------------------------*/
Semi: Procedure                 /* add a semicolon to the end if needed*/
  Arg pname .
  If pname<>'' Then If Right(pname,1)<>';' Then pname=pname';'
Return pname
/*---------------------------------------------------------------------*/
Coma: Procedure                 /* add a coma to the end if needed     */
  Arg pname .
  If pname<>'' Then If Right(pname,1)<>',' Then pname=pname','
Return pname
/*---------------------------------------------------------------------*/
